<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtre:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Selecció de la lletra del terminal</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Lletra:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Mida:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Vista prèvia</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>Marcadors</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Premeu «%1» per veure el terminal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>&amp;Next Tab</source>
        <translation>Pesta&amp;nya següent</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Pestanya anterior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Move Tab &amp;Left</source>
        <translation>Mou la pestanya a &amp;l&apos;esquerra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Move Tab &amp;Right</source>
        <translation>Mou la pestanya a la d&amp;reta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Divideix &amp;horitzontalment el terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Divideix &amp;verticalment el terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Col·lapsa el subterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>Neteja el terminal a&amp;ctiu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Pestanya anterior a l&apos;historial</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <source>&amp;Next Tab in History</source>
        <translation>Pestanya següe&amp;nt a l&apos;historial</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Go to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>&amp;Top Subterminal</source>
        <translation>Sub&amp;terminal superior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>Subterminal in&amp;ferior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>L&amp;eft Subterminal</source>
        <translation>Subterminal &amp;esquerre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>R&amp;ight Subterminal</source>
        <translation>Subterm&amp;inal dret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Copy &amp;Selection</source>
        <translation>Copia la &amp;selecció</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Paste Clip&amp;board</source>
        <translation>Enganxa el p&amp;orta-retalls</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Paste S&amp;election</source>
        <translation>Enganxa la s&amp;elecció</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Zoom &amp;in</source>
        <translation>Ampl&amp;ia el zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>Zoom &amp;out</source>
        <translation>Redueix el z&amp;oom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Zoom rese&amp;t</source>
        <translation>Res&amp;tableix el zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>&amp;Find...</source>
        <translation>&amp;Troba...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Handle history...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>&amp;Save Session</source>
        <translation>De&amp;sa la sessió</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>&amp;Load Session</source>
        <translation>Carrega &amp;la sessió</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>&amp;Toggle Menu</source>
        <translation>Commu&amp;ta el menú</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Rename session</source>
        <translation>Reanomena la sessió</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;New Tab</source>
        <translation>Pestanya &amp;nova</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Pestanya nova a partir d&apos;una de &amp;preestablerta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 terminals &amp;horitzontals</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 terminals &amp;verticals</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 terminal&amp;s</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>&amp;Close Tab</source>
        <translation>Tan&amp;ca la pestanya</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>&amp;New Window</source>
        <translation>Finestra &amp;nova</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferències...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>&amp;Quit</source>
        <translation>S&amp;urt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Oculta les vores de la finestra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>&amp;Show Tab Bar</source>
        <translation>Mo&amp;stra la barra de les pestanyes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Toggle Bookmarks</source>
        <translation>Commuta els marcadors</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Inferior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Top</source>
        <translation>&amp;Superior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>&amp;Right</source>
        <translation>&amp;Dreta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Left</source>
        <translation>&amp;Esquerra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>&amp;Tabs Layout</source>
        <translation>Disposició de les pes&amp;tanyes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;None</source>
        <translation>Se&amp;nse</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Disposi&amp;ció de la barra de desplaçament</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;BlockCursor</source>
        <translation>Cursor de &amp;bloc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>&amp;UnderlineCursor</source>
        <translation>Cursor de s&amp;ubratllat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>&amp;IBeamCursor</source>
        <translation>Cursor de biga &amp;I</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Forma del cursor del teclat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Exit QTerminal</source>
        <translation>Sortida de QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Do not ask again</source>
        <translation>No tornis a preguntar-ho</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Are you sure you want to exit?</source>
        <translation>Esteu segur que voleu sortir?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>Un emulador de terminal lleuger multiplataforma</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Ajusts del terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="31"/>
        <source>Appearance</source>
        <translation>Aparença</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <location filename="../forms/propertiesdialog.ui" line="611"/>
        <source>Behavior</source>
        <translation>Comportament</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>Dreceres</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="55"/>
        <source>Dropdown</source>
        <translation>Desplegament</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="63"/>
        <source>Bookmarks</source>
        <translation>Marcadors</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Oculta la barra de les pestanyes amb només una pestanya</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="275"/>
        <source>Color scheme</source>
        <translation>Esquema de colors</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="371"/>
        <source>Scrollbar position</source>
        <translation>Posició de la barra de desplaçament</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="204"/>
        <source>Start with preset:</source>
        <translation>Comença amb la pestanya preestablerta:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="404"/>
        <source>Show a border around the current terminal</source>
        <translation>Mostra una vora al voltant del terminal actual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="381"/>
        <source>Terminal transparency</source>
        <translation>Transparència del terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="394"/>
        <source>Application transparency</source>
        <translation>Transparència de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="215"/>
        <source>None (single terminal)</source>
        <translation>Sense (només un terminal)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminals horitzontals</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>2 terminals vertically</source>
        <translation>2 terminals verticals</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="230"/>
        <source>4 terminals</source>
        <translation>4 terminals</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="117"/>
        <location filename="../forms/propertiesdialog.ui" line="425"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="148"/>
        <source>Font</source>
        <translation>Lletra</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="184"/>
        <source>&amp;Change...</source>
        <translation>&amp;Canvia...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="454"/>
        <source>Tabs position</source>
        <translation>Posició de les pestanyes</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Widget style</source>
        <translation>Estil de l&apos;estri</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Show the menu bar</source>
        <translation>Mostra la barra de menús</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="335"/>
        <source>Cursor shape</source>
        <translation>Forma del cursor</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="464"/>
        <source>Change window title based on current terminal</source>
        <translation>Canvia el títol de la finestra en funció del terminal actual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="481"/>
        <source>Change window icon based on current terminal</source>
        <translation>Canvia la icona de la finestra en funció del terminal actual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Enable bi-directional text support</source>
        <translation>Habilita la compatibilitat amb el text bidireccional</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>Background image:</source>
        <translation>Imatge de fons:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="290"/>
        <source>Select</source>
        <translation>Selecciona</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="488"/>
        <source>Show terminal size on resize</source>
        <translation>Mostra la mida del terminal amb la redimensió</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="471"/>
        <source>Fixed tab width:</source>
        <translation>Amplada fixa de la pestanya:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="411"/>
        <location filename="../forms/propertiesdialog.ui" line="444"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="361"/>
        <source>Show close button on each tab</source>
        <translation>Mostra el botó de tancament en cadascuna de les pestanyes</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Terminal margin</source>
        <translation>Marge del terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="498"/>
        <source>Use box drawing characters contained in the font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="505"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="508"/>
        <source>No menu bar accelerator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="586"/>
        <source>Emulation</source>
        <translation>Emulació</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="711"/>
        <source>Action after paste</source>
        <translation>Acció després d&apos;enganxar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="748"/>
        <source>Confirm multiline paste</source>
        <translation>Confirma l&apos;enganxament de diverses línies</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="789"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Suprimeix els espais al final de les línies al text enganxat</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="724"/>
        <source>Open new terminals in current working directory</source>
        <translation>Obre els terminals nous al directori de treball actual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="755"/>
        <source>Save Size when closing</source>
        <translation>Desa les mides quan es tanqui</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="796"/>
        <source>Save Position when closing</source>
        <translation>Desa la posició quan es tanqui</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="772"/>
        <source>Ask for confirmation when closing</source>
        <translation>Demana la confirmació quan es tanqui</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="816"/>
        <source>Unlimited history</source>
        <translation>Historial il·limitat</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="782"/>
        <source>History size (in lines)</source>
        <translation>Mida de l&apos;historial (en línies)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="741"/>
        <source>Default $TERM</source>
        <translation>Valor per defecte de $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="632"/>
        <source>Start with this size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Background mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="307"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="312"/>
        <source>Stretch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="317"/>
        <source>Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="322"/>
        <source>Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="327"/>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="495"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="515"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="518"/>
        <source>Use bold font face for intense colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="525"/>
        <source>&amp;Hide Window Borders</source>
        <translation type="unfinished">&amp;Oculta les vores de la finestra</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="595"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="617"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="620"/>
        <source>Handle history command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="639"/>
        <location filename="../forms/propertiesdialog.ui" line="653"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="660"/>
        <source>Get current size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="731"/>
        <source>Open new tab to the right of the active tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="734"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="762"/>
        <source>Close tab on middle-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="823"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="826"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="844"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="874"/>
        <source>Shortcut</source>
        <translation>Dreceres</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="879"/>
        <source>Key</source>
        <translation>Tecles</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="891"/>
        <source>Show on start</source>
        <translation>Mostra-ho al començament</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="898"/>
        <source>Size</source>
        <translation>Mides</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="909"/>
        <source>Height</source>
        <translation>Alçada</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="919"/>
        <location filename="../forms/propertiesdialog.ui" line="936"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="926"/>
        <source>Width</source>
        <translation>Amplada</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="950"/>
        <source>Shortcut:</source>
        <translation>Drecera:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="982"/>
        <source>Edit bookmark file contents</source>
        <translation>Edita el contingut del fitxer dels marcadors</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1004"/>
        <source>Enable bookmarks</source>
        <translation>Habilita els marcadors</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1013"/>
        <source>Bookmark file</source>
        <translation>Fitxer dels marcadors</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1026"/>
        <source>Find...</source>
        <translation>Troba...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1035"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Podeu especificar la ubicació del vostre fitxer de marcadors. Això us permet compartir fàcilment els marcadors amb eines com ara OwnCloud o Dropbox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <source>No scrollbar</source>
        <translation>Cap barra de desplaçament</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Left</source>
        <translation>Esquerra</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Right</source>
        <translation>Dreta</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>BlockCursor</source>
        <translation>Cursor de bloc</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>UnderlineCursor</source>
        <translation>Cursor de subratllat</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>IBeamCursor</source>
        <translation>Cursor de biga I</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>No move</source>
        <translation>Cap moviment</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>Scrolling to top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>Scrolling to bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="390"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="199"/>
        <location filename="../propertiesdialog.cpp" line="294"/>
        <source>System Default</source>
        <translation>Predeterminat del sistema</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="389"/>
        <source>Choose a background image</source>
        <translation>Trieu una imatge de fons</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="466"/>
        <source>Open or create bookmarks file</source>
        <translation>Obre o crea el fitxer dels marcadors</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="108"/>
        <source>Local Bookmarks</source>
        <translation>Marcadors locals</translation>
    </message>
    <message>
        <location filename="../bookmarkswidget.cpp" line="166"/>
        <source>Synchronized Bookmarks</source>
        <translation>Marcadors sincronitzats</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="78"/>
        <location filename="../tabwidget.cpp" line="232"/>
        <source>Shell No. %1</source>
        <translation>Shell núm. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="200"/>
        <source>Tab name</source>
        <translation>Nom de la pestanya</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="201"/>
        <source>New tab name:</source>
        <translation>Nom nou de la pestanya:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="221"/>
        <source>Select new tab title color</source>
        <translation>Selecciona el color del títol de la pestanya nova</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="242"/>
        <source>Close session</source>
        <translation>Tanca la sessió</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="244"/>
        <source>Change title color</source>
        <translation>Canvia el color del títol</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>Càrrega de sessions</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>Llista de les sessions desades:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Finestra principal</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Accions</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Vista</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edita</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>Qu&amp;ant a...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Quant a &amp;Qt...</translation>
    </message>
</context>
</TS>
